@@ -1,6 +1,7 @@
 from ....abstract_type_builder import AbstractTypeBuilder, CacheableTypeBuilder
 from graphene import Field, InputObjectType
 from djraphql.django_models import get_pk_fields_for_model
+from graphql import Undefined
 
 
 class PkInputType(CacheableTypeBuilder, AbstractTypeBuilder):
@@ -21,6 +22,7 @@ class PkInputType(CacheableTypeBuilder, AbstractTypeBuilder):
                 field.name: Field(
                     registry.schema.type_map[field.get_internal_type()],
                     required=True,
+                    default_value=Undefined,
                 )
                 for field in pk_fields
             },
