@@ -4,6 +4,8 @@ from graphene.utils.str_converters import to_snake_case
 from djraphql.django_models import get_field_by_name
 from graphql.execution.values import get_argument_values
 
+IGNORED_FIELDS = set(["__typename"])
+
 
 class QueryFieldsVisitor(Visitor):
     def __init__(self, registry, info):
@@ -32,6 +34,12 @@ class QueryFieldsVisitor(Visitor):
 
         # Get a dictionary of the arguments associated with this field
         field_def = parent_gql_type.fields.get(node.name.value)
+
+        # If the query contains GraphQL-spec-level fields like __typename,
+        # field_def will be None here. We can ignore when this happens.
+        if field_def is None and node.name.value in IGNORED_FIELDS:
+            return
+
         arguments = get_argument_values(
             field_def,
             node,
@@ -44,6 +52,17 @@ class QueryFieldsVisitor(Visitor):
             field = try_get_related_field(model_class, node.name.value)
             if field:
                 self.hello_field(field, arguments, graphql_node=node)
+            else:
+                # The associated model doesn't have a field with the same name.
+                # The only possibility is that this field corresponds to a ComputedField.
+                # If this ComputedField defined a depends_on list, we process it here.
+                entity_class = self.type_lookup[parent_gql_type.name]["entity_class"]
+                for computed_field in entity_class._get_computed_fields():
+                    for dependency in computed_field.depends_on:
+                        field = try_get_related_field(model_class, dependency)
+                        if field:
+                            self.hello_field(field, arguments, graphql_node=node)
+                            self.goodbye_field(field)
 
         # If we're traversing a relationship (e.g., we're entering the
         # "artists" node within the "LabelsMany" query), we need to push the new
